@@ -4,32 +4,32 @@ SetConfiguration <- function(parent=NULL) {
   # Additional functions (subroutines)
 
   UpdatePar <- function() {
-    tmp <- as.integer(tclvalue(nlevels.var))
-    Data("nlevels", if (is.na(tmp)) NULL else tmp)
+    val <- as.integer(tclvalue(nlevels.var))
+    Data("nlevels", if (is.na(val)) NULL else val)
 
-    tmp <- as.numeric(tclvalue(width.var))
-    Data("width", if (is.na(tmp)) NULL else tmp)
+    val <- as.numeric(tclvalue(width.var))
+    Data("width", if (is.na(val)) NULL else val)
 
-    tmp <- as.numeric(tclvalue(cex.pts.var))
-    Data("cex.pts", if (is.na(tmp)) NULL else tmp)
+    val <- as.numeric(tclvalue(cex.pts.var))
+    Data("cex.pts", if (is.na(val)) NULL else val)
 
-    tmp <- as.numeric(tclvalue(asp.yx.var))
-    Data("asp.yx", if (is.na(tmp)) NULL else tmp)
+    val <- as.numeric(tclvalue(asp.yx.var))
+    Data("asp.yx", if (is.na(val)) NULL else val)
 
-    tmp <- as.numeric(tclvalue(asp.zx.var))
-    Data("asp.zx", if (is.na(tmp)) NULL else tmp)
+    val <- as.numeric(tclvalue(asp.zx.var))
+    Data("asp.zx", if (is.na(val)) NULL else val)
 
-    tmp <- as.numeric(tclvalue(vmax.var))
-    Data("vmax", if (is.na(tmp)) NULL else tmp)
+    val <- as.numeric(tclvalue(vmax.var))
+    Data("vmax", if (is.na(val)) NULL else val)
 
-    tmp <- as.numeric(tclvalue(vxby.var))
-    Data("vxby", if (is.na(tmp)) NULL else tmp)
+    val <- as.numeric(tclvalue(vxby.var))
+    Data("vxby", if (is.na(val)) NULL else val)
 
-    tmp <- as.numeric(tclvalue(vyby.var))
-    Data("vyby", if (is.na(tmp)) NULL else tmp)
+    val <- as.numeric(tclvalue(vyby.var))
+    Data("vyby", if (is.na(val)) NULL else val)
 
-    tmp <- as.integer(tclvalue(tgap.var))
-    Data("tgap", if (is.na(tmp)) NULL else tmp)
+    val <- as.integer(tclvalue(tgap.var))
+    Data("tgap", if (is.na(val)) NULL else val)
 
     Data("rkey", as.integer(tclvalue(rkey.var)))
     Data("img.contour", as.integer(tclvalue(img.contour.var)))
@@ -109,12 +109,12 @@ SetConfiguration <- function(parent=NULL) {
   # Open GUI
 
   tclServiceMode(FALSE)
-  tt <- tktoplevel(padx=0, pady=0)
+  tt <- tktoplevel()
   if (!is.null(parent)) {
     tkwm.transient(tt, parent)
-    tmp <- unlist(strsplit(as.character(tkwm.geometry(parent)), "\\+"))
-    tkwm.geometry(tt, paste("+", as.integer(tmp[2]) + 25,
-                            "+", as.integer(tmp[3]) + 25, sep=""))
+    geo <- unlist(strsplit(as.character(tkwm.geometry(parent)), "\\+"))
+    tkwm.geometry(tt, paste("+", as.integer(geo[2]) + 25,
+                            "+", as.integer(geo[3]) + 25, sep=""))
   }
   tktitle(tt) <- "Configuration"
 
@@ -129,11 +129,10 @@ SetConfiguration <- function(parent=NULL) {
   frame0.but.2 <- ttkbutton(frame0, width=12, text="Cancel",
                             command=function() tclvalue(tt.done.var) <- 1)
 
-  tkgrid(frame0.but.1, frame0.but.2)
+  tkgrid(frame0.but.1, frame0.but.2, pady=c(0, 10))
 
-  tkgrid.configure(frame0.but.1, sticky="e", padx=c(4,0), pady=c(5,8))
-  tkgrid.configure(frame0.but.2, sticky="w", padx=c(4,8), pady=c(5,8),
-                   rowspan=2)
+  tkgrid.configure(frame0.but.1, sticky="e", padx=c(0, 4))
+  tkgrid.configure(frame0.but.2, sticky="w", padx=c(0, 10), rowspan=2)
 
   tkpack(frame0, side="bottom", anchor="e")
 
@@ -143,11 +142,11 @@ SetConfiguration <- function(parent=NULL) {
 
   # Frame 1 contains parameters
 
-  frame1 <- ttkframe(pw, relief="flat", borderwidth=5, padding=8)
+  frame1 <- ttkframe(pw, relief="flat", borderwidth=0, padding=10)
 
   txt <- "Approximate number of contour levels"
   frame1.lab.1.1 <- ttklabel(frame1, text=txt)
-  txt <- "Width of plotting window canvas (in)"
+  txt <- "Width of plotting window canvas in inches"
   frame1.lab.2.1 <- ttklabel(frame1, text=txt)
   txt <- "Scaling for point symbols"
   frame1.lab.3.1 <- ttklabel(frame1, text=txt)
@@ -155,13 +154,13 @@ SetConfiguration <- function(parent=NULL) {
   frame1.lab.4.1 <- ttklabel(frame1, text=txt)
   txt <- "Aspect ratio, z / x"
   frame1.lab.5.1 <- ttklabel(frame1, text=txt)
-  txt <- "Maximum arrow length (in)"
+  txt <- "Maximum arrow length in inches"
   frame1.lab.6.1 <- ttklabel(frame1, text=txt)
   txt <- "Increment for sequence of arrows in x direction"
   frame1.lab.7.1 <- ttklabel(frame1, text=txt)
   txt <- "Increment for sequence of arrows in y direction"
   frame1.lab.8.1 <- ttklabel(frame1, text=txt)
-  txt <- "Time gap exceedence level (sec)"
+  txt <- "Time gap exceedence level in seconds"
   frame1.lab.9.1 <- ttklabel(frame1, text=txt)
 
   frame1.ent.1.2 <- ttkentry(frame1, width=8, textvariable=nlevels.var)
@@ -211,19 +210,20 @@ SetConfiguration <- function(parent=NULL) {
            tclvalue(tgap.var) <- CheckEntry("numeric", tclvalue(tgap.var))
          })
 
-  tkgrid(frame1.lab.1.1, frame1.ent.1.2, padx=1, pady=1)
-  tkgrid(frame1.lab.2.1, frame1.ent.2.2, padx=1, pady=1)
-  tkgrid(frame1.lab.3.1, frame1.ent.3.2, padx=1, pady=1)
-  tkgrid(frame1.lab.4.1, frame1.ent.4.2, padx=1, pady=1)
-  tkgrid(frame1.lab.5.1, frame1.ent.5.2, padx=1, pady=1)
-  tkgrid(frame1.lab.6.1, frame1.ent.6.2, padx=1, pady=1)
-  tkgrid(frame1.lab.7.1, frame1.ent.7.2, padx=1, pady=1)
-  tkgrid(frame1.lab.8.1, frame1.ent.8.2, padx=1, pady=1)
-  tkgrid(frame1.lab.9.1, frame1.ent.9.2, padx=1, pady=1)
+  tkgrid(frame1.lab.1.1, frame1.ent.1.2, pady=c(0, 4))
+  tkgrid(frame1.lab.2.1, frame1.ent.2.2, pady=c(0, 4))
+  tkgrid(frame1.lab.3.1, frame1.ent.3.2, pady=c(0, 4))
+  tkgrid(frame1.lab.4.1, frame1.ent.4.2, pady=c(0, 4))
+  tkgrid(frame1.lab.5.1, frame1.ent.5.2, pady=c(0, 4))
+  tkgrid(frame1.lab.6.1, frame1.ent.6.2, pady=c(0, 4))
+  tkgrid(frame1.lab.7.1, frame1.ent.7.2, pady=c(0, 4))
+  tkgrid(frame1.lab.8.1, frame1.ent.8.2, pady=c(0, 4))
+  tkgrid(frame1.lab.9.1, frame1.ent.9.2)
 
   tkgrid.configure(frame1.lab.1.1, frame1.lab.2.1, frame1.lab.3.1,
                    frame1.lab.4.1, frame1.lab.5.1, frame1.lab.6.1,
-                   frame1.lab.7.1, frame1.lab.8.1, frame1.lab.9.1, sticky="e")
+                   frame1.lab.7.1, frame1.lab.8.1, frame1.lab.9.1,
+                   sticky="e", padx=c(0, 2))
   tkgrid.configure(frame1.ent.1.2, frame1.ent.2.2, frame1.ent.3.2,
                    frame1.ent.4.2, frame1.ent.5.2, frame1.ent.6.2,
                    frame1.ent.7.2, frame1.ent.8.2, frame1.ent.9.2, sticky="we")
@@ -232,7 +232,7 @@ SetConfiguration <- function(parent=NULL) {
 
   # Frame 2 contains plot features
 
-  frame2 <- ttkframe(pw, relief="flat", borderwidth=5, padding=8)
+  frame2 <- ttkframe(pw, relief="flat", borderwidth=0, padding=10)
 
   txt <- "reverse legend"
   frame2.chk.01.1 <- ttkcheckbutton(frame2, text=txt, variable=rkey.var)
@@ -254,21 +254,20 @@ SetConfiguration <- function(parent=NULL) {
   txt <- "place tickmarks inside plot region"
   frame2.chk.09.1 <- ttkcheckbutton(frame2, text=txt, variable=ticks.inside.var)
 
-  tkgrid(frame2.chk.01.1, pady=1, sticky="w")
-  tkgrid(frame2.chk.02.1, pady=1, sticky="w")
-  tkgrid(frame2.chk.03.1, pady=1, sticky="w")
-  tkgrid(frame2.chk.04.1, pady=1, sticky="w")
-  tkgrid(frame2.chk.05.1, pady=1, sticky="w")
-  tkgrid(frame2.chk.06.1, pady=1, sticky="w")
-  tkgrid(frame2.chk.07.1, pady=1, sticky="w")
-  tkgrid(frame2.chk.08.1, pady=1, sticky="w")
-  tkgrid(frame2.chk.09.1, pady=1, sticky="w")
+  tkgrid(frame2.chk.01.1, sticky="w", pady=c(0, 2))
+  tkgrid(frame2.chk.02.1, sticky="w", pady=c(0, 2))
+  tkgrid(frame2.chk.03.1, sticky="w", pady=c(0, 2))
+  tkgrid(frame2.chk.04.1, sticky="w", pady=c(0, 2))
+  tkgrid(frame2.chk.05.1, sticky="w", pady=c(0, 2))
+  tkgrid(frame2.chk.06.1, sticky="w", pady=c(0, 2))
+  tkgrid(frame2.chk.07.1, sticky="w", pady=c(0, 2))
+  tkgrid(frame2.chk.08.1, sticky="w", pady=c(0, 2))
+  tkgrid(frame2.chk.09.1, sticky="w")
 
   # Final layout
 
-  tkgrid(frame1, frame2, padx=2, pady=2, sticky="nswe")
+  tkgrid(frame1, frame2, sticky="nswe")
   tkgrid.columnconfigure(pw, 0, weight=2)
-
   tkpack(pw, fill="x", expand=TRUE)
 
   # GUI control
